api.system.components.runtime.v1.host.cachedconfigurations package — Argus-Toolbelt 1.0 documentation

# api.system.components.runtime.v1.host.cachedconfigurations package

## Submodules

## api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear module

Autogenerated API

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `clear_cached_configurations`(hostID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Clear all installed configurations on this host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to clear
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 929, “limit”: 702, “responseCode”: 200, “count”: 307, “data”: [{“id”: 685, “flags”: 743, “scheduledDowntimeFrom”: 646, “scheduledDowntimeTo”: 685, “revision”: 620, “masterID”: 848, “createdTimestamp”: 942730712, “lastUpdatedTimestamp”: 595774267, “lastUpdatedByUser”: {“id”: 332, “customerID”: 166, “userName”: “cblevins”, “name”: “Christopher Robinson”}, “information”: “Back herself practice our game.”, “properties”: {“additionalProperties”: “Sign sell history part choose.”}, “identifiers”: {“additionalProperties”: “Management least pressure under month poor water.”}, “comments”: [{“timestamp”: 637259198, “comment”: “Back identify view series.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Brother build measure.”, “messageTemplate”: “Travel indeed order sing second prepare.”, “field”: “Look major first charge certainly.”, “parameter”: {}, “timestamp”: 50723792}], “currentPage”: 534, “size”: 582}

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `compact_persistence`(hostID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Initiate compacting of persistence database on host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to fetch list from
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 112, “limit”: 554, “responseCode”: 200, “count”: 174, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Paper most their hand marriage leader too war.”, “messageTemplate”: “Let program catch growth front season American.”, “field”: “Meet better property information.”, “parameter”: {}, “timestamp”: 475183925}], “currentPage”: 271, “size”: 47}

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `install_all`(hostID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Install all defined configurations defined for this host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to install on
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 813, “limit”: 618, “responseCode”: 200, “count”: 537, “data”: [{“id”: 182, “flags”: 547, “scheduledDowntimeFrom”: 147, “scheduledDowntimeTo”: 300, “revision”: 862, “masterID”: 709, “createdTimestamp”: 980310256, “lastUpdatedTimestamp”: 113279214, “lastUpdatedByUser”: {“id”: 491, “customerID”: 570, “userName”: “wendyrosario”, “name”: “Jenny Bell”}, “information”: “During most not manager.”, “properties”: {“additionalProperties”: “Early material sign option fear.”}, “identifiers”: {“additionalProperties”: “Notice quite type address suggest.”}, “comments”: [{“timestamp”: 1148157190, “comment”: “Share contain for five.”}]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “It mission like reduce seat.”, “messageTemplate”: “Even receive free quite power apply remember.”, “field”: “Security day east thus director around across available.”, “parameter”: {}, “timestamp”: 878723711}], “currentPage”: 598, “size”: 40}

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `list_persistent_components`(hostID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List persistent components on host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to fetch list from
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `reboot`(hostID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Reboot host (INTERNAL)

  Return type: | `dict`
  Parameters: | hostID (int) – ID of host to reboot
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 534, “limit”: 460, “responseCode”: 200, “count”: 381, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Admit kind hand kitchen sign.”, “messageTemplate”: “Matter before maintain use treatment cause.”, “field”: “Coach plan they control why lawyer who.”, “parameter”: {}, “timestamp”: 1304165437}], “currentPage”: 323, “size”: 125}

`api.system.components.runtime.v1.host.cachedconfigurations.host_cachedconfigurations_clear.` `refresh_host_status`(id: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Request all components on specified host to immediately refresh status (INTERNAL)

  Return type: | `dict`
  Parameters: | id (int) – ID of host to request update from
  Raises: | AuthenticationFailedException – on 401 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {}

## Module contents